diff --git a/templates/base.html b/templates/base.html
index 6434d1d31..27a78dfc0 100644
--- a/templates/base.html
+++ b/templates/base.html
@@ -25,46 +25,20 @@
Home |
CUCC |
expo.survex |
- Handbook |
- {% if user.username %}User:{{ user.username }}
- {% if user.person %}({{ user.person }}){% endif %}
- | Log out {% else %} Register | Log in {% endif %}
+ Handbook |
+ {% if user.person %}User:({{ user.person }})
+ | Log out
+ {% elif user.username %}User:{{ user.username }}
+ | Log out
+ {% else %}
+ | Log in
+ {% endif %}
+ | Register
{% endblock%}
-{% if settings.DEVSERVER %}
-
diff --git a/core/views/expo.py b/core/views/expo.py
index 821decc6f..908948176 100644
--- a/core/views/expo.py
+++ b/core/views/expo.py
@@ -228,7 +228,7 @@ def expowebpage(request, expowebpath, path):
else:
editable = os.access(expowebpath / path, os.W_OK) # are file permissions writeable?
# print(f"EDITABLE ? {editable}\n{head}")
- has_menu = False
+ has_menu = False # this is the old-style AERW-era hand-coded menu on each individual page
menumatch = re.match(r'(.*)
', body, re.DOTALL + re.IGNORECASE)
if menumatch:
has_menu = False
@@ -248,8 +248,8 @@ def expowebpage(request, expowebpath, path):
else:
year = None
- # Determine if this page is part of the handbook
- handbook = path.startswith("handbook")
+ # Determine if this page is part of the troggle handbook
+ troggle = path.startswith("handbook/troggle")
return render(
request,
@@ -262,8 +262,8 @@ def expowebpage(request, expowebpath, path):
"homepage": (path == "index.htm"),
"has_menu": has_menu,
"year": year,
- "handbook": handbook,
"parent_caves": parent_caves,
+ "troggle": troggle,
},
)